<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>SnapSelectionCenter</name>
    <message>
        <location filename="../SnapSelectionCenterInit.js" line="+2"/>
        <source>Center of &amp;Selection</source>
        <translation>選択の中心</translation>
    </message>
</context>
</TS>
